<?php
/**
 *----------------------------------------------------------------------------
 * iCagenda     Events Management Extension for Joomla!
 *----------------------------------------------------------------------------
 * @version     3.8.0 2021-09-29
 *
 * @package     iCagenda.Admin
 * @subpackage  src.Utilities.Thumb
 * @link        https://www.icagenda.com
 *
 * @author      Cyril Rezé
 * @copyright   (c) 2012-2022 Cyril Rezé / iCagenda. All rights reserved.
 * @license     GNU General Public License version 3 or later; see LICENSE.txt
 *
 * @since       3.4
 *----------------------------------------------------------------------------
*/

namespace iCutilities\Thumb;

\defined('_JEXEC') or die;

use iClib\Thumb\Get as iCThumbGet;
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\HTML\HTMLHelper;

/**
 * class icagendaThumb
 */
class Thumb
{
	/**
	 * Return the LARGE thumbnail from an image
	 * Generated by iCagenda with Global Options settings
	 */
	static public function sizeLarge($image, $type = null, $checksize = null)
	{
		$thumbsPath = self::iCagendaImagesPath();

		// Options Large Size
		$thumbOptions = ComponentHelper::getParams('com_icagenda')->get('thumb_large');

		$width   = is_numeric($thumbOptions[0]) ? $thumbOptions[0] : '900';
		$height  = is_numeric($thumbOptions[1]) ? $thumbOptions[1] : '600';
		$quality = is_numeric($thumbOptions[2]) ? $thumbOptions[2] : '100';
		$crop    = ! empty($thumbOptions[3]) ? true : false;

		// Generate large thumb if not exist
		$sizeLarge = iCThumbGet::thumbnail($image, $thumbsPath, 'themes', $width, $height, $quality, $crop, 'ic_large', $type, $checksize);

		return $sizeLarge;
	}

	/**
	 * Return the MEDIUM thumbnail from an image
	 * Generated by iCagenda with Global Options settings
	 */
	static public function sizeMedium($image, $type = null, $checksize = null)
	{
		$thumbsPath = self::iCagendaImagesPath();

		// Options Medium Size
		$thumbOptions = ComponentHelper::getParams('com_icagenda')->get('thumb_medium');

		$width   = is_numeric($thumbOptions[0]) ? $thumbOptions[0] : '300';
		$height  = is_numeric($thumbOptions[1]) ? $thumbOptions[1] : '300';
		$quality = is_numeric($thumbOptions[2]) ? $thumbOptions[2] : '100';
		$crop    = ! empty($thumbOptions[3]) ? true : false;

		// Generate medium thumb if not exist
		$sizeMedium = iCThumbGet::thumbnail($image, $thumbsPath, 'themes', $width, $height, $quality, $crop, 'ic_medium', $type, $checksize);

		return $sizeMedium;
	}

	/**
	 * Return the SMALL thumbnail from an image
	 * Generated by iCagenda with Global Options settings
	 */
	static public function sizeSmall($image, $type = null, $checksize = null)
	{
		$thumbsPath = self::iCagendaImagesPath();

		// Options Small Size
		$thumbOptions = ComponentHelper::getParams('com_icagenda')->get('thumb_small');

		$width   = is_numeric($thumbOptions[0]) ? $thumbOptions[0] : '100';
		$height  = is_numeric($thumbOptions[1]) ? $thumbOptions[1] : '100';
		$quality = is_numeric($thumbOptions[2]) ? $thumbOptions[2] : '100';
		$crop    = ! empty($thumbOptions[3]) ? true : false;

		// Generate small thumb if not exist
		$sizeSmall = iCThumbGet::thumbnail($image, $thumbsPath, 'themes', $width, $height, $quality, $crop, 'ic_small', $type, $checksize);

		return $sizeSmall;
	}

	/**
	 * Return the SMALL thumbnail from an image
	 * Generated by iCagenda with Global Options settings
	 */
	static public function sizeXSmall($image, $type = null, $checksize = null)
	{
		$thumbsPath = self::iCagendaImagesPath();

		// Options XSmall Size
		$thumbOptions = ComponentHelper::getParams('com_icagenda')->get('thumb_xsmall');

		$width   = is_numeric($thumbOptions[0]) ? $thumbOptions[0] : '48';
		$height  = is_numeric($thumbOptions[1]) ? $thumbOptions[1] : '48';
		$quality = is_numeric($thumbOptions[2]) ? $thumbOptions[2] : '80';
		$crop    = ! empty($thumbOptions[3]) ? true : false;

		// Generate xsmall thumb if not exist
		$sizeXSmall = iCThumbGet::thumbnail($image, $thumbsPath, 'themes', $width, $height, $quality, $crop, 'ic_xsmall', $type, $checksize);

		return $sizeXSmall;
	}

	/**
	 * Return the SMALL thumbnail from an image
	 * Generated by iCagenda with Global Options settings
	 */
	static public function sizeOriginal($image)
	{
		if (version_compare(JVERSION, '4.0', 'lt'))
		{
			$img_url = $image;
		}
		else
		{
			$img = HTMLHelper::cleanImageURL($image);

			$img_url = $img->url;
		}

		return $img_url;
	}

	/**
	 * Return the iCagenda images path
	 */
	static public function iCagendaImagesPath()
	{
		// Get media path
		$params_media = ComponentHelper::getParams('com_media');
		$image_path   = $params_media->get('image_path', 'images');

		// Paths to thumbs folder
		$thumbsPath = $image_path . '/icagenda/thumbs';

		return $thumbsPath;
	}
}
